..
   Copyright (C) 2011,2012 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


Introduction
============


.. include:: ../../README.rst
   :start-line: 2


Version history
---------------

.. include:: ../../CHANGELOG.rst
